@@ -4,8 +4,6 @@ import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.List;
 
-import org.gcube.portlets.user.td.columnwidget.client.progress.ResumeDialogListener;
-import org.gcube.portlets.user.td.columnwidget.client.progress.TaskResumeProgressDialog;
 import org.gcube.portlets.user.td.gwtservice.client.rpc.TDGWTServiceAsync;
 import org.gcube.portlets.user.td.gwtservice.shared.Constants;
 import org.gcube.portlets.user.td.gwtservice.shared.OperationsId;
@@ -13,6 +11,9 @@ import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTSessionExpire
 import org.gcube.portlets.user.td.gwtservice.shared.task.InvocationS;
 import org.gcube.portlets.user.td.gwtservice.shared.task.TaskResumeSession;
 import org.gcube.portlets.user.td.gwtservice.shared.task.ValidationsTasksMetadata;
+import org.gcube.portlets.user.td.gwtservice.shared.tr.ConditionCode;
+import org.gcube.portlets.user.td.monitorwidget.client.MonitorDialog;
+import org.gcube.portlets.user.td.monitorwidget.client.MonitorDialogListener;
 import org.gcube.portlets.user.td.tablewidget.client.custom.ValidationCell;
 import org.gcube.portlets.user.td.tablewidget.client.resources.ResourceBundle;
 import org.gcube.portlets.user.td.tablewidget.client.util.UtilsGXT3;
@@ -43,6 +44,7 @@ import com.google.web.bindery.event.shared.EventBus;
 import com.sencha.gxt.core.client.ToStringValueProvider;
 import com.sencha.gxt.core.client.ValueProvider;
 import com.sencha.gxt.core.client.dom.ScrollSupport.ScrollMode;
+import com.sencha.gxt.core.client.util.Margins;
 import com.sencha.gxt.data.shared.IconProvider;
 import com.sencha.gxt.data.shared.ModelKeyProvider;
 import com.sencha.gxt.data.shared.TreeStore;
@@ -73,143 +75,101 @@ import com.sencha.gxt.widget.core.client.treegrid.TreeGrid;
  *         href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a>
  * 
  */
-public class ValidationsTasksPanel extends FramedPanel implements ResumeDialogListener {
+public class ValidationsTasksPanel extends FramedPanel implements
+MonitorDialogListener {
 	protected String WIDTH = "298px";
 	protected String HEIGHT = "520px";
 	protected ValidationsTasksPanel thisPanel;
-	
+
 	protected Menu contextMenu;
-	protected MenuItem resumeItem; 
+	protected MenuItem resumeItem;
 	protected MenuItem resolveItem;
-	
+
 	protected TRId trId;
 	protected VerticalLayoutContainer con;
 	protected EventBus eventBus;
 	protected ValidationsTasksMetadata validationsTasksMetadata;
-	
+
 	protected TreeDataGenerator gen;
 	protected TreeStore<BaseDto> store;
 	protected TreeGrid<BaseDto> tree;
-
-	// TODO remove this variable
-	@SuppressWarnings("rawtypes")
-	protected AbstractCell actionButton = new AbstractCell<Boolean>() {
-
-		@Override
-		public void render(Context context, Boolean value, SafeHtmlBuilder sb) {
-
-			if (value == null) {
-				sb.appendHtmlConstant("");
-			} else {
-				Log.debug("Context: pos=" + context.getIndex() + ", key="
-						+ context.getKey() + ", column=" + context.getColumn());
-				String key = (String) context.getKey();
-				BaseDto d = store.findModelWithKey(key);
-
-				/*
-				 * List<BaseDto> list = ;
-				 * Log.debug("List: ["+list.toString()+"]"); int i = 0; BaseDto
-				 * d=null; for (; i < list.size(); i++) { BaseDto dt =
-				 * list.get(i); if (dt.getId().compareTo((String)
-				 * context.getKey()) == 0) { d=dt;
-				 * Log.debug("Retrieved: "+d+" at pos:"+i); break; } }
-				 */
-
-				String title = "";
-				if (d != null) {
-					Log.debug(d.toString());
-					if (d instanceof ValidationDto) {
-						ValidationDto v = (ValidationDto) d;
-						Log.debug("ValidationDto: [" + v.getId() + ", "
-								+ v.getDescription() + ", " + v.getValid()
-								+ ", " + v.getInvocation() + "]");
-						if (v.getInvocation() != null) {
-							title = v.getInvocation().toString();
-						}
-					}
-				}
-
-				if (value) {
-
-					sb.appendHtmlConstant("<img src='"
-							+ ResourceBundle.INSTANCE.ok().getSafeUri()
-									.asString() + "' alt='true' title='"
-							+ title + "'>");
-
-				} else {
-					sb.appendHtmlConstant("<img src='"
-							+ ResourceBundle.INSTANCE.exit().getSafeUri()
-									.asString() + "' alt='false' title='"
-							+ title + "'>");
-
-				}
-			}
-
-		}
-	};
-
+	private boolean updateTR;
+	
+	
 	class KeyProvider implements ModelKeyProvider<BaseDto> {
 		@Override
 		public String getKey(BaseDto item) {
 			return (item instanceof FolderDto ? "f-" : "v-") + item.getId();
 		}
 	}
-
+	
+	/**
+	 * 
+	 * @param eventBus
+	 */
 	public ValidationsTasksPanel(EventBus eventBus) {
 		super();
 		Log.debug("ValidationsTasksPanel");
 		this.eventBus = eventBus;
-		this.thisPanel=this;
+		this.thisPanel = this;
 		forceLayoutOnResize = true;
+		updateTR=false;
+		init();
 		retrieveCurrentTR();
 
 	}
-
+	
+	/**
+	 * 
+	 * @param trId
+	 * @param eventBus
+	 */
 	public ValidationsTasksPanel(TRId trId, EventBus eventBus) {
 		super();
 		Log.debug("ValidationsTasksPanel: " + trId);
 		this.trId = trId;
 		this.eventBus = eventBus;
-		this.thisPanel=this;
+		this.thisPanel = this;
 		forceLayoutOnResize = true;
-		draw();
-	}
-
-	protected void draw() {
-		if (tree != null) {
-			remove(tree);
-		}
+		updateTR=false;
 		init();
 		retrieveValidations();
 	}
 
+	
+
 	protected void init() {
 		setWidth(WIDTH);
 		setHeight(HEIGHT);
 		setHeaderVisible(false);
 		setBodyBorder(false);
+		
 	}
 
 	protected void createTreeData() {
-		gen = new TreeDataGenerator(validationsTasksMetadata);
-		create();
+		if(updateTR){
+			store.clear();
+			store.commitChanges();
+			addChildrensToStore();
+			
+		} else {
+			create();
+		}
+		store.commitChanges();
+		tree.expandAll();
+		forceLayout();
+		
+		
 	}
 
 	protected void create() {
 		con = new VerticalLayoutContainer();
 		con.setScrollMode(ScrollMode.AUTO);
-		// con.setAdjustForScroll(true);
 
 		store = new TreeStore<BaseDto>(new KeyProvider());
-
-		FolderDto root = gen.getRoot();
-		for (BaseDto base : root.getChildrens()) {
-			store.add(base);
-			if (base instanceof FolderDto) {
-				processFolder(store, (FolderDto) base);
-			}
-		}
-
+		
+		addChildrensToStore();
+	
 		ColumnConfig<BaseDto, String> cc1 = new ColumnConfig<BaseDto, String>(
 				new ToStringValueProvider<BaseDto>("task"), 168, "Task");
 		cc1.setHeader("Task");
@@ -224,23 +184,7 @@ public class ValidationsTasksPanel extends FramedPanel implements ResumeDialogLi
 			}
 		});
 
-		/*
-		 * ColumnConfig<BaseDto, String> cc2 = new ColumnConfig<BaseDto,
-		 * String>( new ValueProvider<BaseDto, String>() {
-		 * 
-		 * @Override public String getValue(BaseDto object) { return object
-		 * instanceof ValidationDto ? ((ValidationDto) object) .getDescription()
-		 * : ""; }
-		 * 
-		 * @Override public void setValue(BaseDto object, String value) { if
-		 * (object instanceof ValidationDto) { ((ValidationDto)
-		 * object).setDescription(value); } }
-		 * 
-		 * @Override public String getPath() { return "description"; } });
-		 * cc2.setHeader("Description");
-		 */
-
-		ColumnConfig<BaseDto, Boolean> cc3 = new ColumnConfig<BaseDto, Boolean>(
+		ColumnConfig<BaseDto, Boolean> cc2 = new ColumnConfig<BaseDto, Boolean>(
 				new ValueProvider<BaseDto, Boolean>() {
 
 					@Override
@@ -261,41 +205,27 @@ public class ValidationsTasksPanel extends FramedPanel implements ResumeDialogLi
 						return "valid";
 					}
 				}, 38, "Valid");
-		cc3.setHeader("Valid");
+		cc2.setHeader("Valid");
 
 		ValidationCell validationButton = new ValidationCell();
 		validationButton.setTrueIcon(ResourceBundle.INSTANCE.ok());
 		validationButton.setFalseIcon(ResourceBundle.INSTANCE.error());
 		validationButton.setTrueTitle("Valid");
 		validationButton.setFalseTitle("Error");
-		/*validationButton.addSelectHandler(new SelectHandler() {
 
-			@Override
-			public void onSelect(SelectEvent event) {
-				Log.debug("Button ValidationCell Pressed");
-				Context context = event.getContext();
-				requestSolution(context);
-
-			}
-		});*/
-
-		cc3.setCell(validationButton);
+		cc2.setCell(validationButton);
 
 		List<ColumnConfig<BaseDto, ?>> l = new ArrayList<ColumnConfig<BaseDto, ?>>();
 		l.add(cc1);
-		// l.add(cc2);
-		l.add(cc3);
+		l.add(cc2);
 		ColumnModel<BaseDto> cm = new ColumnModel<BaseDto>(l);
 
 		tree = new TreeGrid<BaseDto>(store, cm, cc1);
-		// tree.getStyle().setLeafIcon(ResourceBundle.INSTANCE.tableValidation());
-
-		// tree.getView().setStripeRows(true);
-		// tree.getView().setColumnLines(true);
 		tree.getView().setAutoFill(true);
 		tree.setBorders(false);
 		tree.setLoadMask(true);
-		tree.setColumnResize(true);
+		tree.setColumnResize(true);	
+		tree.setAutoExpand(true);
 		tree.getView().setAutoExpandColumn(cc1);
 
 		IconProvider<BaseDto> iconProvider = new IconProvider<BaseDto>() {
@@ -339,15 +269,13 @@ public class ValidationsTasksPanel extends FramedPanel implements ResumeDialogLi
 
 			}
 		});
-		
+
 		createContextMenu();
-		
-		
+
 		ToolBar toolBar = new ToolBar();
 
 		TextButton btnExpandAll = new TextButton();
-		// btnReload.setText("Expand All");
-		btnExpandAll.setIcon(ResourceBundle.INSTANCE.collapseAll12());
+		btnExpandAll.setIcon(ResourceBundle.INSTANCE.magnifierZoomIn());
 		btnExpandAll.setToolTip("Expand All");
 		btnExpandAll.addSelectHandler(new SelectHandler() {
 
@@ -360,8 +288,7 @@ public class ValidationsTasksPanel extends FramedPanel implements ResumeDialogLi
 		toolBar.add(btnExpandAll);
 
 		TextButton btnCollapseAll = new TextButton();
-		// btnReload.setText("Expand All");
-		btnCollapseAll.setIcon(ResourceBundle.INSTANCE.expandAll12());
+		btnCollapseAll.setIcon(ResourceBundle.INSTANCE.magnifierZoomOut());
 		btnCollapseAll.setToolTip("Collapse All");
 		btnCollapseAll.addSelectHandler(new SelectHandler() {
 
@@ -373,54 +300,74 @@ public class ValidationsTasksPanel extends FramedPanel implements ResumeDialogLi
 		});
 		toolBar.add(btnCollapseAll);
 
-		con.add(toolBar, new VerticalLayoutData(1, -1));
-		con.add(tree, new VerticalLayoutData(1, -1));
+		con.add(toolBar, new VerticalLayoutData(1, -1, new Margins(0)));
+		con.add(tree, new VerticalLayoutData(1, -1, new Margins(0)));
 
 		add(con, new MarginData(0));
-
+	}
+	
+	
+	
+	private void addChildrensToStore() {
+		gen = new TreeDataGenerator(validationsTasksMetadata);
+		
+		FolderDto root = gen.getRoot();
+		for (BaseDto base : root.getChildrens()) {
+			store.add(base);
+			if (base instanceof FolderDto) {
+				processFolder(store, (FolderDto) base);
+			}
+		}
+		
+		
 	}
 
-	// TODO
 	protected void requestSolution(Context context) {
 		String key = (String) context.getKey();
 		BaseDto d = store.findModelWithKey(key);
 		requestResolve(d);
 	}
-		
-	protected void requestResolve(BaseDto d){	
-		//String title = "";
+
+	protected void requestResolve(BaseDto d) {
 		if (d != null) {
 			Log.debug(d.toString());
 			if (d instanceof ValidationDto) {
 				ValidationDto v = (ValidationDto) d;
 				Log.debug("ValidationDto: [" + v.getId() + ", "
 						+ v.getDescription() + ", " + v.getValid() + ", "
+						+ v.getConditionCode() + ", "
+						+ v.getValidationColumnColumnId() + ", "
 						+ v.getInvocation() + "]");
 				if (v.getValid()) {
 
 				} else {
 					if (v.getInvocation() != null) {
 						InvocationS invocationS = v.getInvocation();
-						//title = invocationS.toString();
+
 						Long op = invocationS.getOperationId();
 						if (op.compareTo(OperationsId.ChangeToDimensionColumn
 								.toLong()) == 0) {
-							WidgetRequestEvent widgetRequestEvent = new WidgetRequestEvent(
-									WidgetRequestType.CURATIONBYREPLACEBATCHDIALOG);
-							widgetRequestEvent.setTrId(trId);
-							HashMap<String, Object> map = new HashMap<String, Object>();
-							map.put(Constants.REQUEST_PROPERTIES_REFCOLUMN,
-									invocationS.getRefColumn());
-							map.put(Constants.REQUEST_PROPERTIES_COLUMNID,
-									invocationS.getColumnId());
-							map.put(Constants.REQUEST_PROPERTIES_TASKID,
-									invocationS.getTaskId());
-							RequestProperties props = new RequestProperties(map);
-							widgetRequestEvent.setRequestProperties(props);
-							eventBus.fireEvent(widgetRequestEvent);
+							if (v.getConditionCode() == ConditionCode.MissingValueOnExternalReference
+									|| v.getConditionCode() == ConditionCode.AmbiguousValueOnExternalReference) {
+								WidgetRequestEvent widgetRequestEvent = new WidgetRequestEvent(
+										WidgetRequestType.CURATIONBYREPLACEBATCHDIALOG);
+								widgetRequestEvent.setTrId(trId);
+								HashMap<String, Object> map = new HashMap<String, Object>();
+								map.put(Constants.REQUEST_PROPERTIES_INVOCATIONS,
+										invocationS);
+								map.put(Constants.REQUEST_PROPERTIES_CONDITIONCODE,
+										v.getConditionCode());
+								map.put(Constants.REQUEST_PROPERTIES_VALIDATIONCOLUMNCOLUMNID,
+										v.getValidationColumnColumnId());
+
+								RequestProperties props = new RequestProperties(
+										map);
+								widgetRequestEvent.setRequestProperties(props);
+								eventBus.fireEvent(widgetRequestEvent);
+							}
 						} else {
-							//UtilsGXT3.info("Invocation Info", title);
-							
+							// UtilsGXT3.info("Invocation Info", title);
+
 						}
 					}
 				}
@@ -429,8 +376,8 @@ public class ValidationsTasksPanel extends FramedPanel implements ResumeDialogLi
 		}
 
 	}
-	
-	protected void requestResume(BaseDto selected){
+
+	protected void requestResume(BaseDto selected) {
 		if (selected instanceof ValidationDto) {
 			ValidationDto v = (ValidationDto) selected;
 			Log.debug("ValidationDto: [" + v.getId() + ", "
@@ -441,31 +388,32 @@ public class ValidationsTasksPanel extends FramedPanel implements ResumeDialogLi
 					UtilsGXT3.info("Resume", "Is valid, resume not applicable");
 				} else {
 					InvocationS invocationS = v.getInvocation();
-					String taskId=invocationS.getTaskId();
-					if(taskId==null || taskId.isEmpty()){
-						UtilsGXT3.alert("Resume", "TaskId is null, resume not applicable");
+					String taskId = invocationS.getTaskId();
+					if (taskId == null || taskId.isEmpty()) {
+						UtilsGXT3.alert("Resume",
+								"TaskId is null, resume not applicable");
 					} else {
-						TaskResumeSession taskResumeSession=new TaskResumeSession(trId,taskId);
+						TaskResumeSession taskResumeSession = new TaskResumeSession(
+								trId, taskId);
 						startTaskResume(taskResumeSession);
 					}
 				}
 			} else {
-				UtilsGXT3.alert("Resume", "Invocation is null, resume not applicable");
+				UtilsGXT3.alert("Resume",
+						"Invocation is null, resume not applicable");
 			}
 		}
-	
-	}
-	
 
+	}
 
 	protected void createContextMenu() {
 		contextMenu = new Menu();
-		
+
 		resumeItem = new MenuItem();
 		resumeItem.setText("Resume");
 		resumeItem.setIcon(ResourceBundle.INSTANCE.refresh());
 		resumeItem.addSelectionHandler(new SelectionHandler<Item>() {
-			
+
 			@Override
 			public void onSelection(SelectionEvent<Item> event) {
 				BaseDto selected = tree.getSelectionModel().getSelectedItem();
@@ -474,8 +422,6 @@ public class ValidationsTasksPanel extends FramedPanel implements ResumeDialogLi
 			}
 		});
 
-		
-
 		resolveItem = new MenuItem();
 		resolveItem.setText("Resolve");
 		resolveItem.setIcon(ResourceBundle.INSTANCE.plaster());
@@ -483,30 +429,29 @@ public class ValidationsTasksPanel extends FramedPanel implements ResumeDialogLi
 
 			@Override
 			public void onSelection(SelectionEvent<Item> event) {
-				BaseDto selected = tree.getSelectionModel()
-						.getSelectedItem();
+				BaseDto selected = tree.getSelectionModel().getSelectedItem();
 				Log.debug(selected.toString());
 				requestResolve(selected);
-				
+
 			}
 
 		});
-		//contextMenu.add(resumeItem);
-		
+
 		tree.setContextMenu(contextMenu);
-		
+
 		tree.addBeforeShowContextMenuHandler(new BeforeShowContextMenuHandler() {
-			
+
 			@Override
 			public void onBeforeShowContextMenu(BeforeShowContextMenuEvent event) {
-				Menu contextMenu=event.getMenu();
-				
-				BaseDto selected = tree.getSelectionModel()
-						.getSelectedItem();
+				Menu contextMenu = event.getMenu();
+
+				BaseDto selected = tree.getSelectionModel().getSelectedItem();
 				if (selected instanceof ValidationDto) {
 					ValidationDto v = (ValidationDto) selected;
 					Log.debug("ValidationDto: [" + v.getId() + ", "
 							+ v.getDescription() + ", " + v.getValid() + ", "
+							+ v.getConditionCode() + ", "
+							+ v.getValidationColumnColumnId() + ", "
 							+ v.getInvocation() + "]");
 					if (v.getInvocation() != null) {
 						if (v.getValid()) {
@@ -517,30 +462,35 @@ public class ValidationsTasksPanel extends FramedPanel implements ResumeDialogLi
 						} else {
 							InvocationS invocationS = v.getInvocation();
 							Long op = invocationS.getOperationId();
+							// TODO Add all cases
 							if (op.compareTo(OperationsId.ChangeToDimensionColumn
-									.toLong()) == 0) {
+									.toLong()) == 0
+									&& (v.getConditionCode() == ConditionCode.MissingValueOnExternalReference || v
+											.getConditionCode() == ConditionCode.AmbiguousValueOnExternalReference)) {
 								contextMenu.clear();
 								contextMenu.add(resolveItem);
 								contextMenu.add(resumeItem);
 								tree.setContextMenu(contextMenu);
 							} else {
+
 								contextMenu.clear();
 								contextMenu.add(resumeItem);
 								tree.setContextMenu(contextMenu);
+
 							}
 						}
-					}  else {
+					} else {
 						contextMenu.clear();
 						tree.setContextMenu(contextMenu);
 						event.setCancelled(true);
 					}
-					
+
 				} else {
 					contextMenu.clear();
 					tree.setContextMenu(contextMenu);
 					event.setCancelled(true);
 				}
-				
+
 			}
 		});
 	}
@@ -575,14 +525,14 @@ public class ValidationsTasksPanel extends FramedPanel implements ResumeDialogLi
 	}
 
 	public void update() {
+		updateTR=true;
 		retrieveCurrentTR();
-		forceLayout();
 	}
 
 	public void update(TRId trId) {
 		this.trId = trId;
-		draw();
-		forceLayout();
+		updateTR=true;
+		retrieveValidations();
 	}
 
 	protected void retrieveCurrentTR() {
@@ -603,7 +553,7 @@ public class ValidationsTasksPanel extends FramedPanel implements ResumeDialogLi
 			public void onSuccess(TRId result) {
 				Log.debug("retrieved " + result);
 				trId = result;
-				draw();
+				retrieveValidations();
 
 			}
 
@@ -619,59 +569,151 @@ public class ValidationsTasksPanel extends FramedPanel implements ResumeDialogLi
 		}
 	}
 
-	protected void startTaskResume(TaskResumeSession taskResumeSession){
+	protected void startTaskResume(TaskResumeSession taskResumeSession) {
 		Log.debug(taskResumeSession.toString());
-		TDGWTServiceAsync.INSTANCE.startTaskResume(taskResumeSession, new AsyncCallback<Void>() {
+		TDGWTServiceAsync.INSTANCE.startTaskResume(taskResumeSession,
+				new AsyncCallback<String>() {
 
-			@Override
-			public void onFailure(Throwable caught) {
-				if (caught instanceof TDGWTSessionExpiredException) {
-					eventBus.fireEvent(new SessionExpiredEvent(
-							SessionExpiredType.EXPIREDONSERVER));
-				} else {
-					Log.debug(caught.getLocalizedMessage());
-					UtilsGXT3.alert("Error in Resume",
-							caught.getLocalizedMessage());
-				}
-				
-			}
+					@Override
+					public void onFailure(Throwable caught) {
+						if (caught instanceof TDGWTSessionExpiredException) {
+							eventBus.fireEvent(new SessionExpiredEvent(
+									SessionExpiredType.EXPIREDONSERVER));
+						} else {
+							Log.debug(caught.getLocalizedMessage());
+							UtilsGXT3.alert("Error in Resume",
+									caught.getLocalizedMessage());
+						}
 
-			@Override
-			public void onSuccess(Void result) {
-				TaskResumeProgressDialog taskResumeProgressDialog=new TaskResumeProgressDialog(eventBus);
-				taskResumeProgressDialog.addResumeDialogListener(thisPanel);
-				taskResumeProgressDialog.show();
-				
-			}
-		
-		});
+					}
+
+					@Override
+					public void onSuccess(String taskId) {
+						openMonitorDialog(taskId);
+						
+					}
+
+				});
 	}
+
 	
+	
+	protected void close() {
+		/*if (parent != null) {
+			parent.close();
+		}*/
+	}
+
+	// /
+	protected void openMonitorDialog(String taskId) {
+		MonitorDialog monitorDialog = new MonitorDialog(taskId, eventBus);
+		monitorDialog.addProgressDialogListener(this);
+		monitorDialog.show();
+	}
+
 	@Override
-	public void resumeComplete(TRId trId) {
+	public void operationComplete(TRId trId) {
 		ChangeTableWhy why = ChangeTableWhy.TABLEUPDATED;
 		ChangeTableRequestEvent changeTableRequestEvent = new ChangeTableRequestEvent(
 				ChangeTableRequestType.TASKRESUME, trId, why);
 		eventBus.fireEvent(changeTableRequestEvent);
-		
+		close();
 	}
 
 	@Override
-	public void resumeFailed(Throwable caught, String reason) {
-		UtilsGXT3.alert("Error in Resume", reason);
-		
+	public void operationFailed(Throwable caught, String reason, String details) {
+		UtilsGXT3.alert(reason, details);
+		close();
+
 	}
 
 	@Override
-	public void resumeStopped(TRId trId, String reason, String details) {
+	public void operationStopped(TRId trId, String reason, String details) {
 		ChangeTableWhy why = ChangeTableWhy.TABLECURATION;
 		ChangeTableRequestEvent changeTableRequestEvent = new ChangeTableRequestEvent(
 				ChangeTableRequestType.TASKRESUME, trId, why);
 		eventBus.fireEvent(changeTableRequestEvent);
-		
+		close();
+
+	}
+
+	@Override
+	public void operationAborted() {
+		close();
+
+	}
+
+	@Override
+	public void operationPutInBackground() {
+		close();
+
 	}
 	
-	
-	
+
+	// @SuppressWarnings("rawtypes")
+	// protected AbstractCell actionButton = new AbstractCell<Boolean>() {
+	//
+	// @Override
+	// public void render(Context context, Boolean value, SafeHtmlBuilder sb) {
+	//
+	// if (value == null) {
+	// sb.appendHtmlConstant("");
+	// } else {
+	// Log.debug("Context: pos=" + context.getIndex() + ", key="
+	// + context.getKey() + ", column=" + context.getColumn());
+	// String key = (String) context.getKey();
+	// BaseDto d = store.findModelWithKey(key);
+	//
+	// /*
+	// * List<BaseDto> list = ;
+	// * Log.debug("List: ["+list.toString()+"]"); int i = 0; BaseDto
+	// * d=null; for (; i < list.size(); i++) { BaseDto dt =
+	// * list.get(i); if (dt.getId().compareTo((String)
+	// * context.getKey()) == 0) { d=dt;
+	// * Log.debug("Retrieved: "+d+" at pos:"+i); break; } }
+	// */
+	//
+	// String title = "";
+	// if (d != null) {
+	// Log.debug(d.toString());
+	// if (d instanceof ValidationDto) {
+	// ValidationDto v = (ValidationDto) d;
+	// Log.debug("ValidationDto: [" + v.getId() + ", "
+	// + v.getDescription() + ", " + v.getValid()
+	// + ", " + v.getInvocation() + "]");
+	// if (v.getInvocation() != null) {
+	// title = v.getInvocation().toString();
+	// }
+	// }
+	// }
+	//
+	// if (value) {
+	//
+	// sb.appendHtmlConstant("<img src='"
+	// + ResourceBundle.INSTANCE.ok().getSafeUri()
+	// .asString() + "' alt='true' title='"
+	// + title + "'>");
+	//
+	// } else {
+	// sb.appendHtmlConstant("<img src='"
+	// + ResourceBundle.INSTANCE.exit().getSafeUri()
+	// .asString() + "' alt='false' title='"
+	// + title + "'>");
+	//
+	// }
+	// }
+	//
+	// }
+	// };
+
+	/*
+	 * validationButton.addSelectHandler(new SelectHandler() {
+	 * 
+	 * @Override public void onSelect(SelectEvent event) {
+	 * Log.debug("Button ValidationCell Pressed"); Context context =
+	 * event.getContext(); requestSolution(context);
+	 * 
+	 * } });
+	 */
 
 }
